Titanoboa Testing
#################

Because ``moccasin`` uses ``titanoboa`` under the hood, you can use all the same testing features that ``titanoboa`` has, including:

- `Fuzzing <https://titanoboa.readthedocs.io/en/latest/guides/testing/fuzzing_strategies/#fuzzing-strategies>`_ 
- `Native import syntax <https://titanoboa.readthedocs.io/en/latest/guides/scripting/native_import_syntax/>`_ 
- `And more <https://titanoboa.readthedocs.io/en/latest/>`_